#
# spec file for package java-1_7_0-openjdk-plugin
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define priority        17147
%define javaver         1.7.0
%define java_name       java-1_7_0-openjdk
# use a same name of alternatives as Sun/IBM Java
%define javaplugin      javaplugin
%define pluginsdir      %{_libdir}/browser-plugins
%define sdkdir          java-%{javaver}-openjdk-%{javaver}
%define pluginpath      %{_libdir}/%{name}/lib
%define pluginname      IcedTeaPlugin.so
Name:           %{java_name}-plugin
Version:        1.6.1
Release:        3.18
Summary:        Java Web Start and plugin implementation
License:        GPL-2.0-with-classpath-exception
Group:          Development/Languages/Java
Url:            http://icedtea.classpath.org
Source0:        http://icedtea.classpath.org/download/source/icedtea-web-%{version}.tar.gz
Patch1000:      icedtea-web-suse-desktop-files.patch
BuildRequires:  %{java_name}-devel >= %{javaver}
# IcedTeaPlugin build requirements.
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  glib2-devel
BuildRequires:  npapi-sdk
BuildRequires:  pkgconfig >= 0.9.0
BuildRequires:  procps
BuildRequires:  rhino
BuildRequires:  update-desktop-files
BuildRequires:  zip
BuildRequires:  zlib-devel
# to make sure the new package is installed in time of post
Requires(post): %{java_name}
# Post requires alternatives to install tool alternatives.
Requires(post): update-alternatives
# Postun requires alternatives to uninstall tool alternatives.
Requires(postun): update-alternatives
Suggests:       icedtea-web-javadoc
# bnc#737105/FATE#313084
Supplements:    packageand(browser(npapi):java-openjdk)
Provides:       icedtea-web = %{version}-%{release}
Provides:       java-plugin = %{javaver}
Obsoletes:      icedtea-web < %{version}-%{release}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} <= 1130
BuildRequires:  xorg-x11-devel
%else
BuildRequires:  libX11-devel
%endif
# owns javadocdir
# javapackages-tools now includes jpackage-utils
%if 0%{?suse_version} > 1230
BuildRequires:  javapackages-tools
%else
BuildRequires:  jpackage-utils
%endif

%description
The IcedTea-Web project provides a Free Software web browser plugin running
applets written in the Java programming language and an implementation of Java
Web Start, originally based on the NetX project.

%prep
%setup -q -n icedtea-web-%{version}
%patch1000 -p1

%build
autoreconf -fi
%configure \
	--with-jdk-home=%{_jvmdir}/%{sdkdir} \
	--with-jre-home=%{_jvmdir}/%{sdkdir}/jre \
	--prefix=%{_libdir}/%{name} \
	--bindir=%{_libdir}/%{name}/bin \
	--libdir=%{_libdir}/%{name}/lib \
	--datadir=%{_libdir}/%{name}/share \
	--mandir=%{_libdir}/%{name}/share/man \
	--disable-docs \
	--with-pkgversion=suse-%{release}-%{_arch}

make %{?_smp_mflags} V=1

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}

# Install desktop files.
install -d -m 755 %{buildroot}%{_libdir}/%{name}/share/{applications,pixmaps}
cp javaws.png %{buildroot}%{_libdir}/%{name}/share/pixmaps
for d in javaws itweb-settings policyeditor; do
   install -m 0644 $d.desktop %{buildroot}/%{_libdir}/%{name}/share/applications/
    %suse_update_desktop_file $d
done

# Compress manpages
for i in %{buildroot}%{_libdir}/%{name}/share/man/man1/*.1; do
   gzip -9 -n $i
done

%fdupes -s %{buildroot}

# needs for sle-11-sp1 and openSUSE evergreen
export NO_BRP_CHECK_BYTECODE_VERSION=true

# Create the alternatives files
mkdir -p %{buildroot}%{_sysconfdir}/alternatives/
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_datadir}/applications/
mkdir -p %{buildroot}%{_datadir}/pixmaps/
mkdir -p %{buildroot}%{_mandir}/man1/
mkdir -p %{buildroot}%{pluginsdir}
touch %{buildroot}%{_sysconfdir}/alternatives/javaplugin.so
touch %{buildroot}%{_sysconfdir}/alternatives/javaws
touch %{buildroot}%{_sysconfdir}/alternatives/javaws.desktop
touch %{buildroot}%{_sysconfdir}/alternatives/javaws.png
touch %{buildroot}%{_sysconfdir}/alternatives/itweb-settings
touch %{buildroot}%{_sysconfdir}/alternatives/itweb-settings.desktop
touch %{buildroot}%{_sysconfdir}/alternatives/policyeditor
touch %{buildroot}%{_sysconfdir}/alternatives/itweb-settings.1.gz
touch %{buildroot}%{_sysconfdir}/alternatives/javaws.1.gz
touch %{buildroot}%{_sysconfdir}/alternatives/policyeditor.1.gz
touch %{buildroot}%{_sysconfdir}/alternatives/policyeditor.desktop
ln -sf %{_sysconfdir}/alternatives/javaplugin.so %{buildroot}%{pluginsdir}/javaplugin.so
ln -sf %{_sysconfdir}/alternatives/javaws %{buildroot}%{_bindir}/javaws
ln -sf %{_sysconfdir}/alternatives/javaws.desktop %{buildroot}%{_datadir}/applications/javaws.desktop
ln -sf %{_sysconfdir}/alternatives/javaws.png %{buildroot}%{_datadir}/pixmaps/javaws.png
ln -sf %{_sysconfdir}/alternatives/itweb-settings %{buildroot}%{_bindir}/itweb-settings
ln -sf %{_sysconfdir}/alternatives/itweb-settings.desktop %{buildroot}%{_datadir}/applications/itweb-settings.desktop
ln -sf %{_sysconfdir}/alternatives/policyeditor %{buildroot}%{_bindir}/policyeditor
ln -sf %{_sysconfdir}/alternatives/javaws.1.gz %{buildroot}%{_mandir}/man1/javaws.1.gz
ln -sf %{_sysconfdir}/alternatives/itweb-settings.1.gz %{buildroot}%{_mandir}/man1/itweb-settings.1.gz
ln -sf %{_sysconfdir}/alternatives/policyeditor.desktop %{buildroot}%{_datadir}/applications/policyeditor.desktop
ln -sf %{_sysconfdir}/alternatives/policyeditor.1.gz %{buildroot}%{_mandir}/man1/policyeditor.1.gz

%post
update-alternatives \
  --install %{pluginsdir}/javaplugin.so %{javaplugin} \
  %{pluginpath}/%{pluginname} %{priority} \
  --slave %{_bindir}/javaws javaws %{_libdir}/%{name}/bin/javaws \
  --slave %{_datadir}/applications/javaws.desktop javaws.desktop \
  %{_libdir}/%{name}/share/applications/javaws.desktop \
  --slave %{_datadir}/pixmaps/javaws.png javaws.png \
  %{_libdir}/%{name}/share/pixmaps/javaws.png \
  --slave %{_bindir}/itweb-settings itweb-settings %{_libdir}/%{name}/bin/itweb-settings \
  --slave %{_datadir}/applications/itweb-settings.desktop itweb-settings.desktop \
  %{_libdir}/%{name}/share/applications/itweb-settings.desktop \
  --slave %{_bindir}/policyeditor policyeditor %{_libdir}/%{name}/bin/policyeditor \
  --slave %{_datadir}/applications/policyeditor.desktop policyeditor.desktop \
  %{_libdir}/%{name}/share/applications/policyeditor.desktop \
  --slave %{_mandir}/man1/javaws.1.gz javaws.1.gz \
  %{_libdir}/%{name}/share/man/man1/javaws.1.gz \
  --slave %{_mandir}/man1/itweb-settings.1.gz itweb-settings.1.gz \
  %{_libdir}/%{name}/share/man/man1/itweb-settings.1.gz \
  --slave %{_mandir}/man1/policyeditor.1.gz policyeditor.1.gz \
  %{_libdir}/%{name}/share/man/man1/policyeditor.1.gz

%postun
if [ $1 -eq 0 ]; then
update-alternatives --remove %{javaplugin} \
    %{pluginpath}/%{pluginname}
fi

%files
%defattr(-,root,root,-)
%doc NEWS README COPYING
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/bin
%dir %{_libdir}/%{name}/lib
%dir %{_libdir}/%{name}/share
%dir %{_libdir}/%{name}/share/applications
%dir %{_libdir}/%{name}/share/icedtea-web
%dir %{_libdir}/%{name}/share/man
%dir %{_libdir}/%{name}/share/man/man1
%dir %{_libdir}/%{name}/share/pixmaps
%ghost %{_sysconfdir}/alternatives/javaplugin.so
%ghost %{_sysconfdir}/alternatives/javaws
%ghost %{_sysconfdir}/alternatives/javaws.desktop
%ghost %{_sysconfdir}/alternatives/javaws.png
%ghost %{_sysconfdir}/alternatives/itweb-settings
%ghost %{_sysconfdir}/alternatives/itweb-settings.desktop
%ghost %{_sysconfdir}/alternatives/policyeditor
%ghost %{_sysconfdir}/alternatives/itweb-settings.1.gz
%ghost %{_sysconfdir}/alternatives/javaws.1.gz
%ghost %{_sysconfdir}/alternatives/policyeditor.1.gz
%ghost %{_sysconfdir}/alternatives/policyeditor.desktop
%{_bindir}/itweb-settings
%{_bindir}/javaws
%{_bindir}/policyeditor
%{pluginsdir}/javaplugin.so
%{_datadir}/applications/itweb-settings.desktop
%{_datadir}/applications/javaws.desktop
%{_datadir}/applications/policyeditor.desktop
%{_datadir}/pixmaps/javaws.png
%{_mandir}/man1/itweb-settings.1.gz
%{_mandir}/man1/javaws.1.gz
%{_mandir}/man1/policyeditor.1.gz
%{_libdir}/%{name}/bin/itweb-settings
%{_libdir}/%{name}/bin/javaws
%{_libdir}/%{name}/bin/policyeditor
%{pluginpath}/%{pluginname}
%{_libdir}/%{name}/share/applications/itweb-settings.desktop
%{_libdir}/%{name}/share/applications/javaws.desktop
%{_libdir}/%{name}/share/applications/policyeditor.desktop
%{_libdir}/%{name}/share/pixmaps/javaws.png
%{_libdir}/%{name}/share/icedtea-web/javaws_splash.png
%{_libdir}/%{name}/share/icedtea-web/netx.jar
%{_libdir}/%{name}/share/icedtea-web/plugin.jar
%{_libdir}/%{name}/share/man/man1/*.1*
%exclude %{_libdir}/%{name}/share/man/*/man1

%changelog
* Mon Sep 14 2015 fstrba@suse.com
- Update to 1.6.1
  * Enabled Entry-Point attribute check
  * permissions sandbox and signed app and unsigned app with
    permissions all-permissions now run in sandbox instead of not
  at all.
  * fixed DownloadService
  * comments in deployment.properties now should persists load/save
  * fixed bug in caching of files with query
  * fixed issues with recreating of existing shortcut
  * trustAll/trustNone now processed correctly
  * headless no longer shows dialogues
  * RH1231441 Unable to read the text of the buttons of the security
    dialogue
  * Fixed RH1233697 icedtea-web: applet origin spoofing
    (CVE-2015-5235, bsc#944208)
  * Fixed RH1233667 icedtea-web: unexpected permanent authorization
    of unsigned applets (CVE-2015-5234, bsc#944209)
  * MissingALACAdialog made available also for unsigned applications
    (but ignoring actual manifest value) and fixed
  * NetX
  - fixed issues with -html shortcuts
  - fixed issue with -html receiving garbage in width and height
  * PolicyEditor
  - file flag made to work when used standalone
  - file flag and main argument cannot be used in combination
- Removed patch:
  * icedtea-web-1.6-tail.patch
  - Upstreamed
* Wed Jul 22 2015 fstrba@suse.com
- Added patch:
  * icedtea-web-1.6-tail.patch
  - Fix generation of man-pages with some versions of "tail"
* Mon Jul 20 2015 fstrba@suse.com
- Update to 1.6
  * Massively improved offline abilities. Added Xoffline switch to
    force work without inet connection.
  * Improved to be able to run with any JDK
  * JDK 6 and older no longer supported
  * JDK 8 support added (URLPermission granted if applicable)
  * JDK 9 supported
  * Added support for Entry-Point manifest attribute
  * Added KEY_ENABLE_MANIFEST_ATTRIBUTES_CHECK deployment property
    to control scan of Manifest file
  * starting arguments now accept also -- abbreviations
  * Added new documentation
  * Added support for menu shortcuts - both javaws
    applications/applets and html applets are supported
  * added support for -html switch for javaws. Now you can run most
    of the applets without browser at all
  * Control Panel
  - PR1856: ControlPanel UI improvement for lower resolutions
    (800*600)
  * NetX
  - PR1858: Java Console accepts multi-byte encodings
  - PR1859: Java Console UI improvement for lower resolutions
    (800*600)
  - RH1091563: [abrt] icedtea-web-1.5-2.fc20: Uncaught exception
    java.lang.ClassCastException in method
    sun.applet.PluginAppletViewer$8.run()
  - Dropped support for long unmaintained -basedir argument
  - Returned support for -jnlp argument
  - RH1095311, PR574 -  References class sun.misc.Ref removed in
    OpenJDK 9 - fixed, and so buildable on JDK9
  * Plugin
  - PR1743 - Intermittant deadlock in PluginRequestProcessor
  - PR1298 - LiveConnect - problem setting array elements (applet
    variables) from JS
  - RH1121549: coverity defects
  - Resolves method overloading correctly with superclass
    heirarchy distance
  * PolicyEditor
  - codebases can be renamed in-place, copied, and pasted
  - codebase URLs can be copied to system clipboard
  - displays a progress dialog while opening or saving files
  - codebases without permissions assigned save to file anyway
    (and re-appear on next open)
  - PR1776: NullPointer on save-and-exit
  - PR1850: duplicate codebases when launching from security dialogs
  - Fixed bug where clicking "Cancel" on the "Save before Exiting"
    dialog could result in the editor exiting without saving
    changes
  - Keyboard accelerators and mnemonics greatly improved
  - "File - New" allows editing a new policy without first
    selecting the file to save to
  * Common
  - PR1769: support signed applets which specify Sandbox
    permissions in their manifests
  * Temporary Permissions in security dialog now multi-selectable
    and based on PolicyEditor permissions
* Wed Nov 26 2014 fstrba@suse.com
- Update to 1.5.2 (fate#318956)
  * NetX
  - RH1095311, PR574 -  References class sun.misc.Ref removed in
    OpenJDK 9 - fixed, and so buildable on JDK9
  - RH1154177 - decoded file needed from cache
  - fixed NPE  in https dialog
  - empty codebase behaves  as "."
- Remove patch: icedtea-web-1.5.1-java9.patch
  * Upstreamed in this version
* Thu Oct 16 2014 gber@opensuse.org
- Modify icedtea-web-suse-desktop-files.patch to use use
  X-GNOME-DesktopSettings as well
* Thu Oct 16 2014 fstrba@suse.com
- Conditional dependencies on libX11 and/or xorg-x11-devel
  * make possible to build for SLE11
* Mon Oct 13 2014 gber@opensuse.org
- Modify icedtea-web-suse-desktop-files.patch to use the Settings
  instead of the System category, policyeditor.desktop and
  itweb.desktop are tools for mamanging per-user preferences and
  not system applications
* Thu Oct  9 2014 badshah400@gmail.com
- Modify icedtea-web-suse-desktop-files.patch to add
  X-GNOME-Sundry to list of categories for policyeditor.desktop
  and itweb.desktop, so that both items are included in the
  Sundry app-folder in GNOME.
* Fri Oct  3 2014 fstrba@suse.com
- Add patch: icedtea-web-1.5.1-java9.patch
  * Allow building against java9
* Tue Sep 23 2014 fstrba@suse.com
- Modified patch:
  * icedtea-web-suse-desktop-files.patch
  - Change categories for the desktop files to keep SLE and
    openSUSE in sync
* Mon Sep 22 2014 fstrba@suse.com
- Update to 1.5.1
  * Massively improved offline abilities.
  * Improved to be able to run with any JDK
  * JDK 8 support added (URLPermission granted if applicable)
  * Added DE and PL localizations
  * Added KEY_ENABLE_MANIFEST_ATTRIBUTES_CHECK deployment property
    to control scan of Manifest file
  * Control Panel
  - PR1856: ControlPanel UI improvement for lower resolutions (800*600)
  * NetX
  - PR1858: Java Console accepts multi-byte encodings
  - PR1859: Java Console UI improvement for lower resolutions (800*600)
  - RH1091563: [abrt] icedtea-web-1.5-2.fc20: Uncaught exception
    java.lang.ClassCastException in method
    sun.applet.PluginAppletViewer$8.run()
  * Plugin
  - PR1743 - Intermittant deadlock in PluginRequestProcessor
  - RH1121549: coverity defects
  * PolicyEditor
  - codebases without permissions assigned save to file anyway (and
    re-appear on next open)
  - PR1776: NullPointer on save-and-exit
  - Custom permissions are properly formatted
- Remove upstreamed patch:
  * icedtea-web-1.5-no-return-in-nonvoid-function.patch
* Thu Aug 21 2014 fstrba@suse.com
- Touch link targets in order to silence test of broken symlinks
* Thu Aug  7 2014 fcrozat@suse.com
- Update icedtea-web-suse-desktop-files.patch: Add
  X-GNOME-SystemSettings category.
* Mon Jul 28 2014 tchvatal@suse.com
- Update alternatives code to match docu.
* Tue Jul 22 2014 fstrba@suse.com
- Modified patch:
  * icedtea-web-suse-desktop-files.patch
  - Change categories for itweb-settings.desktop
* Wed Jul 16 2014 fstrba@suse.com
- Update to 1.5
  * Remove build dependency on xulrunner
- Deleted atches:
  * icedtea-web-1.0.2-no-return-in-nonvoid-function.patch,
    icedtea-web-1.1-moonlight-symbol-chash.patch: not needed in
    icedtea-web 1.5
- Added patch:
  * icedtea-web-1.5-no-return-in-nonvoid-function.patch: fix bugs
    uncovered by post-build tests
- Split package into three:
  * java-1_7_0-openjdk-plugin: builds a plugin for java-1_7_0-openjdk
  * java-1_8_0-openjdk-plugin: builds a plugin for java-1_8_0-openjdk
  * icedtea-web: builds common javadoc documentation for both
    packages.
- The used plugin is determined by alternatives
* Fri Sep 20 2013 mvyskocil@suse.com
- update to 1.4.1 (bnc#840572)
  * Improved and cleaned Temporary internet files panel
  * NetX
  - PR1465 - java.io.FileNotFoundException while trying to download a JAR file
  - PR1473 - javaws should not depend on name of local file
  * Plugin
  - PR854: Resizing an applet several times causes 100%% CPU load
  * Security Updates
  - CVE-2013-4349, RH869040: Heap-based buffer overflow after triggering event attached to applet
    CVE-2012-4540 nit fixed in icedtea-web 1.4
  * Misc
  - reproducers tests are enabled in dist-tarball
  - application context support for  OpenJDK build 25 and higher
  - small patches into rhino support and
  - PR1533: Inherit jnlp.packEnabled and jnlp.versionEnabled like other properties
- need jpackage-utils on older distros
- run more tests in %%check
- drop icedtea-web-AppContext.patch, already upstream
* Fri Sep 13 2013 mvyskocil@suse.com
- add javapackages-tools to build requires
* Thu Jun 20 2013 mvyskocil@suse.com
- fix bnc#825880: icedtea-web broken by last openjdk security update
  icedtea-web-AppContext.patch
* Tue May  7 2013 mvyskocil@suse.com
- update to 1.4 (bnc#818768)
  * Added cs, de, pl localization
  * Splash screen for javaws and plugin
  * Better error reporting for plugin via Error-splash-screen
  * All IcedTea-Web dialogues are centered to middle of active screen
  * Download indicator made compact for more then one jar
  * User can select its own JVM via itw-settings and deploy.properties.
  * Added extended applets security settings and dialogue
  * Security updates
  - CVE-2013-1926, RH916774: Class-loader incorrectly shared for applets with same relative-path.
  - CVE-2013-1927, RH884705: fixed gifar vulnerabilit
  - CVE-2012-3422, RH840592: Potential read from an uninitialized memory location
  - CVE-2012-3423, RH841345: Incorrect handling of not 0-terminated strings
  * NetX
  - PR1027: DownloadService is not supported by IcedTea-Web
  - PR725: JNLP applications will prompt for creating desktop shortcuts every time they are run
  - PR1292: Javaws does not resolve versioned jar names with periods correctly
  * Plugin
  - PR1106: Buffer overflow in plugin table-
  - PR1166: Embedded JNLP File is not supported in applet tag
  - PR1217: Add command line arguments for plugins
  - PR1189: Icedtea-plugin requires code attribute when using jnlp_href
  - PR1198: JSObject is not passed to javascript correctly
  - PR1260: IcedTea-Web should not rely on GTK
  - PR1157: Applets can hang browser after fatal exception
  - PR580: http://www.horaoficial.cl/ loads improperly
  * Common
  - PR1049: Extension jnlp's signed jar with the content of only META-INF/* is considered
  - PR955: regression: SweetHome3D fails to run
  - PR1145: IcedTea-Web can cause ClassCircularityError
  - PR1161: X509VariableTrustManager does not work correctly with OpenJDK7
  - PR822: Applets fail to load if jars have different signers
  - PR1186: System.getProperty("deployment.user.security.trusted.cacerts") is null
  - PR909: The Java applet at http://de.gosupermodel.com/games/wardrobegame.jsp fails
  - PR1299: WebStart doesn't read socket proxy settings from firefox correctly
* Wed Apr 17 2013 mvyskocil@suse.com
- update to 1.3.2 (bnc#815596)
- Security Updates
  * CVE-2013-1927, RH884705: fixed gifar vulnerability
  * CVE-2013-1926, RH916774: Class-loader incorrectly shared for applets with same relative-path.
- Common
  * Added new option in itw-settings which allows users to set JVM arguments
    when plugin is initialized.
- NetX
  * PR580: http://www.horaoficial.cl/ loads improperly
- Plugin
  * PR1260: IcedTea-Web should not rely on GTK
  obsoletes icedtea-web-remove-gtk-dep.patch
  * PR1157: Applets can hang browser after fatal exception
* Sat Jan 19 2013 zaitor@opensuse.org
- Add icedtea-web-remove-gtk-dep.patch, build icedtea-web without
  GTK. Plugin now works in both gtk2 and gtk3 based browsers.
* Wed Jan 16 2013 mvyskocil@suse.com
- limit the provides/obsoletes to architectures, where -plugin package
  existed and don't pollute shiny new arm with an old garbage
* Tue Jan 15 2013 dmueller@suse.com
- handle the package renaming on arm properly
* Wed Nov  7 2012 mvyskocil@suse.com
- update to 1.3.1 (bnc#787846)
- Security Updates
  * CVE-2012-4540, RH869040: Heap-based buffer overflow after triggering event attached to applet
- Common
  - PR1161: X509VariableTrustManager does not work correctly with OpenJDK7
    fixes the self-signed issue (mentioned in bnc#784859, bnc#785333, bnc#786775)
* Mon Sep 10 2012 mvyskocil@suse.cz
- update to 1.3 (bnc#779001)
- New features:
  * Web Start launch errors are now printed to give proper indication as to the
    cause
  * Significant performance improvement when loading applets that refer to
    missing classes
  * Support for latest versions of Chromium
  * Security warning dialog improvements to better clarify security request
  * Support build with GTK2 and GTK3
  * Cookie write support (i.e set cookies in browser via Java/Applet)
- Common:
  * Applet window icon improved
- Plug-in:
  * PR975: Ignore classpaths specified in jar manifests when using jnlp_href
  * PR1011: Treat folders as such when specified in archive tags
  * PR855: AppletStub getDocumentBase() now returns full URL
  * PR722: Unsigned META-INF entries are ignored
  * PR861: Jars can now load from non codebase hosts
  * PR1106: Icedtea 1.2.1 crashes Firefox 14
- Web Start:
  * PR898: Large signed JNLP files now supported
  * PR811: URLs with spaces now handled correctly
- drop already upstreamed icetea-web-1.2.1-old-xulrunner-typo.patch
* Wed Aug  8 2012 mvyskocil@suse.cz
- fix PR1106: Icedtea 1.2.1 crashes Firefox 14
  * http://icedtea.classpath.org/bugzilla/show_bug.cgi?id=1106
* Thu Aug  2 2012 mvyskocil@suse.cz
- update to 1.2.1 (bnc#773458)
- Security Updates
  * CVE-2012-3422, RH840592: Potential read from an uninitialized memory location
  * CVE-2012-3423, RH841345: Incorrect handling of not 0-terminated strings
- NetX
  * PR898: signed applications with big jnlp-file doesn't start (webstart affect like "frozen")
  * PR811: javaws is not handling urls with spaces (and other characters needing encoding) correctly
  * 816592: icedtea-web not loading GeoGebra java applets in Firefox or Chrome
- Plugin
  * PR863: Error passing strings to applet methods in Chromium
  * PR895: IcedTea-Web searches for missing classes on each loadClass or findClass
  * PR518: NPString.utf8characters not guaranteed to be nul-terminated
- Common
  * RH838417: Disambiguate signed applet security prompt from certificate warning
  * RH838559: Disambiguate signed applet security prompt from certificate warning
* Mon Jun 25 2012 mvyskocil@suse.cz
- require java-1_7_0-openjdk for build and installation
* Tue Mar  6 2012 mvyskocil@suse.cz
- update to 1.2
- New features:
  * Signed JNLP support
  * Support for client authentication certificates
  * Cache size enforcement now supported via itweb-settings
  * Applet parameter passing through JNLP files now supported
  * Better icons for access warning dialog
  * Security Dialog UI revamped to make it look less threatening when appropriate
- Fixes (plugin, webstart, common)
  * PR618: Can't install OpenDJ, JavaWebStart fails with Input stream is null error
  * PR765: JNLP file with all resource jars marked as 'lazy' fails to validate signature and stops the launch of application
  * PR788: Elluminate Live! is not working
  * PR804: javaws launcher incorrectly handles file names with spaces
  * PR820, bnc#746895: IcedTea-Web 1.1.3 crashing Firefox when loading Citrix XenApp
  * PR838: IcedTea plugin crashes with chrome browser when javascript is executed
  * PR852: Classloader not being flushed after last applet from a site is closed
  * RH586194: Unable to connect to connect with Juniper VPN client
  * PR771: IcedTea-Web certificate verification code does not use the right API
  * PR742: IcedTea-Web checks certs only upto 1 level deep before declaring them untrusted.
  * PR789: typo in jrunscript.sh
  * PR808: javaws is unable to start, when missing jars are enumerated before main jar
  * RH738814: Access denied at ssl handshake
  * Support for authenticating using client certificates
- fix bnc#737105/FATE#313084: add Supplements: packageand(broswer(npapi):java-openjdk)
  ensures the web plugin is pulled in when openjdk and capable browser is installed
* Mon Mar  5 2012 mvyskocil@suse.cz
- enable make check in respective section
* Mon Nov 14 2011 mvyskocil@suse.cz
- update to 1.1.4 (fixes bnc#729870)
  - RH742515, CVE-2011-3377: IcedTea-Web: second-level domain subdomains and
    suffix domain SOP bypass
  - PR778: Jar download and server certificate verification deadlock
* Mon Oct 24 2011 mvyskocil@suse.cz
- update to 1.1.3:
  - PR782: Support building against npapi-sdk as well
  * drop the added patch
  - PR794: IcedTea-Web does not work if a Web Start app jar has a
    Class-Path element in the manifest
- icedtea-web-npapi-sdk-r5.patch for build with npapi-sdk we have
  in openSUSE
* Mon Oct 10 2011 gber@opensuse.org
- fix icedtea-web-suse-desktop-files.patch, itweb-settings is a
  desktop setting and should not show up twice in two unrelated
  top-level menus; also add a trailing semicolon
* Thu Sep 15 2011 mvyskocil@suse.cz
- Build with a npapi-sdk and xulrunner-devel from openSUSE 12.1
* Tue Sep  6 2011 cfarrell@suse.com
- license update: GPL-2.0-with-classpath-exception
  SPDX syntax. See http://spdx.org/licenses
* Fri Sep  2 2011 mvyskocil@suse.cz
- update to 1.1.2
  * PR749: sun.applet.PluginStreamHandler#handleMessage(String) really slow
  * RH718693: MindTerm SSH Applet doesn’t work
  * PR768: Signed applets/Web Start apps don’t work with OpenJDK7 and up
  * PR769: IcedTea-Web does not work with some ssl sites with OpenJDK7
  * RH734081: Javaws cannot use proxy settings from Firefox
  * New (--with-jre-home=) option to allow use with only JRE installed
- use a common jre location libdir/jvm/jre instead of openjdk6
- obsoleted CVE patches
* Wed Jul 20 2011 mvyskocil@suse.cz
- fix bnc#704309 - VUL-0: icedtea/icedtea-web two issues
  * CVE-2011-2513
  * CVE-2011-2514
- use --with-java instead of patching of launchers as
  suggested by upstream
* Fri Jul  8 2011 mvyskocil@suse.cz
- fix bnc#704419 - Use correct path in IcedteaPlugin.so
  * allow plugin usage without -devel package installed
  * fix lanchers location from JAVA to JRE
  * icedtea-1.1-use-jre-in-launchers.patch
* Thu Jun 30 2011 mvyskocil@suse.cz
- fic bnx#702825 - IcedTeaPlugin.so gives undefined symbol
  * fix the icedtea-web-1.1-moonlight-symbol-clash.patch
* Fri Jun 10 2011 mvyskocil@suse.cz
- Update to 1.1 - triggered by icedtea-1.10.2 security update (bnc#698739)
- New features:
  * IcedTea-Web now installs to a FHS-compliant location
  * Binary launchers have been replaced with simple shell scripts
  * Proxy Auto Config files are now usable
  * Applications using jnlp.versionEnabled and jnlp.packEnabled are now supported
  * Can now use codebase_lookup=false with applets
  * itweb-settings now supports clearing cache
- Common fixes
  * Apps calling loadClass get a proper a ClassNotFoundException if class is
    not found, rather than a null value
  * Applets and JNLP apps using SSL/TLS now function correctly
-  Web Start implementation (javaws) fixes:
  * The Web Start implementation can now use proxy settings from Firefox
  * Web Start applications now use the correct default browser set by the user
  * Closing javaws -about no longer throws exceptions
  * Cache files are removed properly
- Plug-in fixes:
  * Applets from the same page to use the same classloader (MS LiveMeeting,
    www.uk.map24.com, etc.)
  * NetDania banking application now works (bnc#608132)
  * Sound now works with runescape.com (bnc#542457)
  * Firefox 4 no longer freezes if the applet calls showDocument()
  * Firefox 4 and chromium stability has been vastly improved with a rewrite of
    the plug-in threading model
* Tue Apr 12 2011 mvyskocil@suse.cz
- Initial SUSE packaging of 1.0.2
  * just follow upstream's split of web tools to icedtea-web
